@@ -1,10 +1,9 @@
 /*
  * This file is part of MQT QFR library which is released under the MIT license.
- * See file README.md or go to http://iic.jku.at/eda/research/quantum/ for more information.
+ * See file README.md or go to https://www.cda.cit.tum.de/research/quantum/ for more information.
  */
 
-#ifndef QFR_QFT_H
-#define QFR_QFT_H
+#pragma once
 
 #include "QuantumComputation.hpp"
 
@@ -23,5 +22,3 @@ namespace qc {
         void createCircuit();
     };
 } // namespace qc
-
-#endif //QFR_QFT_H
