@@ -1,10 +1,9 @@
 /*
  * This file is part of MQT QFR library which is released under the MIT license.
- * See file README.md or go to http://iic.jku.at/eda/research/quantum/ for more information.
+ * See file README.md or go to https://www.cda.cit.tum.de/research/quantum/ for more information.
  */
 
-#ifndef QFR_SCANNER_H
-#define QFR_SCANNER_H
+#pragma once
 
 #include "Token.hpp"
 
@@ -59,5 +58,3 @@ namespace qasm {
         }
     };
 } // namespace qasm
-
-#endif //QFR_SCANNER_H
